[llvm-commits] [parallel] CVS: llvm/include/llvm/Assembly/AsmAnnotationWriter.h

Misha Brukman brukman at cs.uiuc.edu
Wed Mar 10 19:23:06 PST 2004


Changes in directory llvm/include/llvm/Assembly:

AsmAnnotationWriter.h updated: 1.2 -> 1.2.4.1

---
Log message:

Merge from trunk.

---
Diffs of the changes:  (+9 -3)

Index: llvm/include/llvm/Assembly/AsmAnnotationWriter.h
diff -u llvm/include/llvm/Assembly/AsmAnnotationWriter.h:1.2 llvm/include/llvm/Assembly/AsmAnnotationWriter.h:1.2.4.1
--- llvm/include/llvm/Assembly/AsmAnnotationWriter.h:1.2	Tue Nov 11 16:41:31 2003
+++ llvm/include/llvm/Assembly/AsmAnnotationWriter.h	Wed Mar 10 19:22:24 2004
@@ -31,9 +31,15 @@
   // the start of a function.
   virtual void emitFunctionAnnot(const Function *F, std::ostream &OS) {}
 
-  // emitBasicBlockAnnot - This may be implemented to emit a string right after
-  // the basic block label, but before the first instruction in the block.
-  virtual void emitBasicBlockAnnot(const BasicBlock *BB, std::ostream &OS) {}
+  // emitBasicBlockStartAnnot - This may be implemented to emit a string right
+  // after the basic block label, but before the first instruction in the block.
+  virtual void emitBasicBlockStartAnnot(const BasicBlock *BB, std::ostream &OS){
+  }
+
+  // emitBasicBlockEndAnnot - This may be implemented to emit a string right
+  // after the basic block.
+  virtual void emitBasicBlockEndAnnot(const BasicBlock *BB, std::ostream &OS){
+  }
 
   // emitInstructionAnnot - This may be implemented to emit a string right
   // before an instruction is emitted.





More information about the llvm-commits mailing list